===============================
clustrous
===============================

.. image:: https://img.shields.io/travis/eddiejessup/clustrous.svg
        :target: https://travis-ci.org/eddiejessup/clustrous

.. image:: https://img.shields.io/pypi/v/clustrous.svg
        :target: https://pypi.python.org/pypi/clustrous


Linkage clustering

* Free software: BSD license
* Documentation: https://clustrous.readthedocs.org.

Features
--------

* TODO
